package com.dzeio.openhealth

import android.app.Application
import android.content.Intent
import android.content.SharedPreferences
import android.os.Process
import android.util.Log
import androidx.preference.PreferenceManager
import com.dzeio.openhealth.ui.ErrorActivity
import com.google.android.material.color.DynamicColors
import dagger.hilt.android.HiltAndroidApp
import java.util.Locale
import kotlin.system.exitProcess

@HiltAndroidApp
class Application : Application() {
    companion object {
        const val TAG = "OpenHealth"
    }

    override fun onCreate() {

        // Application Error Handling
        Thread.setDefaultUncaughtExceptionHandler { paramThread, paramThrowable ->
            //Log error to logcat if it wasn't done before
            Log.e(TAG, "En error was detected in the Thread ${paramThread.id}, trying to go to ErrorActivity")

            // send use to the Error Activity
            val intent = Intent(applicationContext, ErrorActivity::class.java)

            intent.addFlags(Intent.FLAG_ACTIVITY_NEW_TASK or Intent.FLAG_ACTIVITY_CLEAR_TOP or Intent.FLAG_ACTIVITY_EXCLUDE_FROM_RECENTS)
            intent.putExtra("error", paramThrowable.stackTraceToString())
            intent.putExtra("threadId", paramThread.id)
            startActivity(intent)
            Log.e(TAG, "Activity should have started")

            Process.killProcess(Process.myPid())
            exitProcess(10)
        }

        // Android Dynamics Colors
        DynamicColors.applyToActivitiesIfAvailable(this)

        // Change application Language based on setting
        val preferences: SharedPreferences = PreferenceManager.getDefaultSharedPreferences(this)
        val lang = preferences.getString("global_language", Locale.getDefault().language)
        if (lang == null) {
            Log.e(TAG, "lang is null")
        } else {
            val locale = Locale(lang)
            Locale.setDefault(locale)
        }

//        val overrideConfiguration = baseContext.resources.configuration
//        overrideConfiguration.locale = locale
//        val context: Context = createConfigurationContext(overrideConfiguration)
//        val resources: Resources = context.resources

        super.onCreate()
    }
}
