package com.dzeio.openhealth.data.step

import androidx.room.ColumnInfo
import androidx.room.Entity
import androidx.room.PrimaryKey
import java.text.DateFormat
import java.util.Calendar
import java.util.Date
import java.util.Locale
import java.util.TimeZone

@Entity()
data class Step(
    @PrimaryKey(autoGenerate = true) var id: Long = 0,
    var value: Int = 0,
    /**
     * Timestamp down to an hour
     *
     * ex: 2022-09-22 10:00:00
     */
    @ColumnInfo(index = true)
    var timestamp: Long = 0,
    var source: String = "OpenHealth"
) {

    init {
        if (timestamp == 0L) {
            val cal = Calendar.getInstance(TimeZone.getTimeZone("UTC"))
            cal.set(Calendar.MINUTE, 0)
            cal.set(Calendar.SECOND, 0)
            cal.set(Calendar.MILLISECOND, 0)

            timestamp = cal.timeInMillis
        }
    }

    fun formatTimestamp(): String {
        val formatter = DateFormat.getDateTimeInstance(
            DateFormat.SHORT,
            DateFormat.SHORT,
            Locale.getDefault()
        )
        return formatter.format(Date(this.timestamp))
    }

    fun isToday(): Boolean {
        val it = Calendar.getInstance(TimeZone.getTimeZone("UTC"))
        it.timeInMillis = timestamp
        it.set(Calendar.HOUR, 0)

        val cal = Calendar.getInstance(TimeZone.getTimeZone("UTC"))

        cal.set(Calendar.HOUR, 0)
        cal.set(Calendar.MINUTE, 0)
        cal.set(Calendar.SECOND, 0)
        cal.set(Calendar.MILLISECOND, 0)
        return it.timeInMillis == cal.timeInMillis
    }

    fun isCurrent(): Boolean {
        val cal = Calendar.getInstance(TimeZone.getTimeZone("UTC"))
        cal.set(Calendar.MINUTE, 0)
        cal.set(Calendar.SECOND, 0)
        cal.set(Calendar.MILLISECOND, 0)
        return timestamp == cal.timeInMillis
    }
}
