package com.dzeio.openhealth.ui.settings

import android.content.SharedPreferences
import android.content.res.Configuration
import android.os.Bundle
import android.text.InputType
import android.util.Log
import androidx.preference.EditTextPreference
import androidx.preference.ListPreference
import androidx.preference.PreferenceFragmentCompat
import androidx.preference.PreferenceManager
import com.dzeio.openhealth.BuildConfig
import com.dzeio.openhealth.R
import com.dzeio.openhealth.units.UnitFactory
import java.util.Locale

class SettingsFragment : PreferenceFragmentCompat() {

    val settings: SharedPreferences by lazy {
        PreferenceManager.getDefaultSharedPreferences(requireContext())
    }

    override fun onCreatePreferences(savedInstanceState: Bundle?, rootKey: String?) {
        setPreferencesFromResource(R.xml.preferences, rootKey)

        // Force only numbers on Goal
        val weightGoal = findPreference<EditTextPreference>("weight_goal")
        weightGoal?.apply {
            setOnBindEditTextListener {
                it.inputType = InputType.TYPE_CLASS_NUMBER
            }
            val value = settings.getString("weight_goal", null)
            val modifier = UnitFactory.mass(settings.getString("weight_unit", null) ?: "kilogram")
            if (value != null && value.isNotEmpty()) {
                text = (value.toFloat() * modifier.modifier).toString()
            }
            setOnPreferenceChangeListener { _, newValue ->
                val alue = ((newValue as String).toInt() / modifier.modifier).toInt().toString()
                settings.edit()
                    .putString(
                        "weight_goal",
                        alue
                    )
                    .apply()
                text = alue
                return@setOnPreferenceChangeListener false
            }
        }

        // 251 kg
        // 553 lb

        findPreference<ListPreference>("weight_unit")?.apply {
            setOnPreferenceChangeListener { _, newValue ->
                val unit = settings.getString("weight_unit", "kilogram")
                    ?: return@setOnPreferenceChangeListener true
                val goal = settings.getString("weight_goal", null)
                    ?: return@setOnPreferenceChangeListener true
                val modifier = UnitFactory.mass(newValue as String)
                val oldModifier = UnitFactory.mass(unit)
                val value =
                    (goal.toFloat() / oldModifier.modifier * modifier.modifier).toInt().toString()
                settings.edit()
                    .putString(
                        "weight_goal",
                        value
                    )
                    .apply()
                weightGoal?.text = value
                return@setOnPreferenceChangeListener true
            }
        }

        val languagesPreference = findPreference<ListPreference>("global_language")
        Log.d("TAG", Locale.getDefault().language)
        languagesPreference?.apply {
            entries = BuildConfig.LOCALES
            entryValues = BuildConfig.LOCALES
            setDefaultValue(Locale.getDefault().language)
        }

        // Update App Locale
        languagesPreference?.setOnPreferenceChangeListener { _, newValue ->
            val locale = Locale(newValue as String)
            Locale.setDefault(locale)
            val config = Configuration()
            config.locale = locale

            requireActivity().baseContext.resources.updateConfiguration(
                config,
                requireActivity().baseContext.resources.displayMetrics
            )

            requireActivity().recreate()

            return@setOnPreferenceChangeListener true
        }
    }
}
